# coding: utf-8

"""
    LUSID API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List
from pydantic.v1 import BaseModel, Field, conlist
from lusid.models.field_definition import FieldDefinition
from lusid.models.field_value import FieldValue

class ReferenceData(BaseModel):
    """
    ReferenceData
    """
    field_definitions: conlist(FieldDefinition) = Field(..., alias="fieldDefinitions")
    values: conlist(FieldValue) = Field(...)
    __properties = ["fieldDefinitions", "values"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ReferenceData:
        """Create an instance of ReferenceData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in field_definitions (list)
        _items = []
        if self.field_definitions:
            for _item in self.field_definitions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fieldDefinitions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in values (list)
        _items = []
        if self.values:
            for _item in self.values:
                if _item:
                    _items.append(_item.to_dict())
            _dict['values'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ReferenceData:
        """Create an instance of ReferenceData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ReferenceData.parse_obj(obj)

        _obj = ReferenceData.parse_obj({
            "field_definitions": [FieldDefinition.from_dict(_item) for _item in obj.get("fieldDefinitions")] if obj.get("fieldDefinitions") is not None else None,
            "values": [FieldValue.from_dict(_item) for _item in obj.get("values")] if obj.get("values") is not None else None
        })
        return _obj
