# coding: utf-8

"""
    LUSID API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PeriodType(str, Enum):
    """
    PeriodType
    """

    """
    allowed enum values
    """
    DAILY = 'Daily'
    WEEKLY = 'Weekly'
    MONTHLY = 'Monthly'
    QUARTERLY = 'Quarterly'
    ANNUALLY = 'Annually'

    @classmethod
    def from_json(cls, json_str: str) -> PeriodType:
        """Create an instance of PeriodType from a JSON string"""
        return PeriodType(json.loads(json_str))
