# coding: utf-8

"""
    LUSID API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PropertyDefinitionType(str, Enum):
    """
    PropertyDefinitionType
    """

    """
    allowed enum values
    """
    VALUEPROPERTY = 'ValueProperty'
    DERIVEDDEFINITION = 'DerivedDefinition'

    @classmethod
    def from_json(cls, json_str: str) -> PropertyDefinitionType:
        """Create an instance of PropertyDefinitionType from a JSON string"""
        return PropertyDefinitionType(json.loads(json_str))
